fnss.topologies.topology.Topology.degree_iter — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.6.1 documentation »

# fnss.topologies.topology.Topology.degree_iter

`Topology.` `degree_iter`(nbunch=None, weight=None)

  Return an iterator for (node, degree).

  The node degree is the number of edges adjacent to the node.

  Parameters: | nbunch : iterable container, optional (default=all nodes) A container of nodes. The container will be iterated through once. weight : string or None, optional (default=None) The edge attribute that holds the numerical value used as a weight. If None, then each edge has weight 1. The degree is the sum of the edge weights adjacent to the node.
  Returns: | nd_iter : an iterator The iterator returns two-tuples of (node, degree).

  See also

  `degree`

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2,3])
      >>> list(G.degree_iter(0)) # node 0 with degree 1
      [(0, 1)]
      >>> list(G.degree_iter([0,1]))
      [(0, 1), (1, 2)]

### Navigation

- index
- modules |
- modules |
- FNSS 0.6.1 documentation »